==> kubernetes-model-extensions-6.4.1-sources.jar: io/fabric8/kubernetes/api/model/extensions/IngressRuleFluentImpl.java <==
package io.fabric8.kubernetes.api.model.extensions;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class IngressRuleFluentImpl<A extends IngressRuleFluent<A>> extends BaseFluent<A> implements IngressRuleFluent<A>{
  public IngressRuleFluentImpl() {
  }
  public IngressRuleFluentImpl(IngressRule instance) {
    this.withHost(instance.getHost()); 
    this.withHttp(instance.getHttp()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String host;
  private HTTPIngressRuleValueBuilder http;
  private Map<String,Object> additionalProperties;
  public String getHost() {
    return this.host;
  }
  public A withHost(String host) {
    this.host=host; return (A) this;
  }
  public Boolean hasHost() {
    return this.host != null;
  }
  
  /**
   * This method has been deprecated, please use method buildHttp instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPIngressRuleValue getHttp() {
    return this.http!=null ?this.http.build():null;
  }
  public HTTPIngressRuleValue buildHttp() {
    return this.http!=null ?this.http.build():null;
  }
  public A withHttp(HTTPIngressRuleValue http) {
    _visitables.get("http").remove(this.http);
    if (http!=null){ this.http= new HTTPIngressRuleValueBuilder(http); _visitables.get("http").add(this.http);} else { this.http = null; _visitables.get("http").remove(this.http); } return (A) this;
  }
  public Boolean hasHttp() {
    return this.http != null;
  }
  public IngressRuleFluent.HttpNested<A> withNewHttp() {
    return new IngressRuleFluentImpl.HttpNestedImpl();
  }
  public IngressRuleFluent.HttpNested<A> withNewHttpLike(HTTPIngressRuleValue item) {
    return new IngressRuleFluentImpl.HttpNestedImpl(item);
  }
  public IngressRuleFluent.HttpNested<A> editHttp() {
    return withNewHttpLike(getHttp());
  }
  public IngressRuleFluent.HttpNested<A> editOrNewHttp() {
    return withNewHttpLike(getHttp() != null ? getHttp(): new HTTPIngressRuleValueBuilder().build());
  }
  public IngressRuleFluent.HttpNested<A> editOrNewHttpLike(HTTPIngressRuleValue item) {
    return withNewHttpLike(getHttp() != null ? getHttp(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    IngressRuleFluentImpl that = (IngressRuleFluentImpl) o;
    if (host != null ? !host.equals(that.host) :that.host != null) return false;
    if (http != null ? !http.equals(that.http) :that.http != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(host,  http,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (host != null) { sb.append("host:"); sb.append(host + ","); }
    if (http != null) { sb.append("http:"); sb.append(http + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class HttpNestedImpl<N> extends HTTPIngressRuleValueFluentImpl<IngressRuleFluent.HttpNested<N>> implements IngressRuleFluent.HttpNested<N>,Nested<N>{
    HttpNestedImpl(HTTPIngressRuleValue item) {
      this.builder = new HTTPIngressRuleValueBuilder(this, item);
    }
    HttpNestedImpl() {
      this.builder = new HTTPIngressRuleValueBuilder(this);
    }
    HTTPIngressRuleValueBuilder builder;
    public N and() {
      return (N) IngressRuleFluentImpl.this.withHttp(builder.build());
    }
    public N endHttp() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-extensions-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/extensions/IngressRuleFluentImpl.java <==
package io.fabric8.kubernetes.api.model.extensions;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class IngressRuleFluentImpl<A extends IngressRuleFluent<A>> extends BaseFluent<A> implements IngressRuleFluent<A>{
  public IngressRuleFluentImpl() {
  }
  public IngressRuleFluentImpl(IngressRule instance) {
    if (instance != null) {
      this.withHost(instance.getHost());
      this.withHttp(instance.getHttp());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String host;
  private HTTPIngressRuleValueBuilder http;
  private Map<String,Object> additionalProperties;
  public String getHost() {
    return this.host;
  }
  public A withHost(String host) {
    this.host=host; return (A) this;
  }
  public Boolean hasHost() {
    return this.host != null;
  }
  
  /**
   * This method has been deprecated, please use method buildHttp instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPIngressRuleValue getHttp() {
    return this.http!=null ?this.http.build():null;
  }
  public HTTPIngressRuleValue buildHttp() {
    return this.http!=null ?this.http.build():null;
  }
  public A withHttp(HTTPIngressRuleValue http) {
    _visitables.get("http").remove(this.http);
    if (http!=null){ this.http= new HTTPIngressRuleValueBuilder(http); _visitables.get("http").add(this.http);} else { this.http = null; _visitables.get("http").remove(this.http); } return (A) this;
  }
  public Boolean hasHttp() {
    return this.http != null;
  }
  public IngressRuleFluentImpl.HttpNested<A> withNewHttp() {
    return new IngressRuleFluentImpl.HttpNestedImpl();
  }
  public IngressRuleFluentImpl.HttpNested<A> withNewHttpLike(HTTPIngressRuleValue item) {
    return new IngressRuleFluentImpl.HttpNestedImpl(item);
  }
  public IngressRuleFluentImpl.HttpNested<A> editHttp() {
    return withNewHttpLike(getHttp());
  }
  public IngressRuleFluentImpl.HttpNested<A> editOrNewHttp() {
    return withNewHttpLike(getHttp() != null ? getHttp(): new HTTPIngressRuleValueBuilder().build());
  }
  public IngressRuleFluentImpl.HttpNested<A> editOrNewHttpLike(HTTPIngressRuleValue item) {
    return withNewHttpLike(getHttp() != null ? getHttp(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IngressRuleFluentImpl that = (IngressRuleFluentImpl) o;
    if (!java.util.Objects.equals(host, that.host)) return false;

    if (!java.util.Objects.equals(http, that.http)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(host,  http,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (host != null) { sb.append("host:"); sb.append(host + ","); }
    if (http != null) { sb.append("http:"); sb.append(http + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class HttpNestedImpl<N> extends HTTPIngressRuleValueFluentImpl<IngressRuleFluentImpl.HttpNested<N>> implements IngressRuleFluentImpl.HttpNested<N>,Nested<N>{
    HttpNestedImpl(HTTPIngressRuleValue item) {
      this.builder = new HTTPIngressRuleValueBuilder(this, item);
    }
    HttpNestedImpl() {
      this.builder = new HTTPIngressRuleValueBuilder(this);
    }
    HTTPIngressRuleValueBuilder builder;
    public N and() {
      return (N) IngressRuleFluentImpl.this.withHttp(builder.build());
    }
    public N endHttp() {
      return and();
    }
    
  }
  
}
